@@ -52,7 +52,7 @@
 report_metrics <- function(data, cols, cross = NULL, metric = FALSE, ..., index = FALSE, factors = FALSE, clusters = FALSE, effect = FALSE, title = TRUE, close = TRUE, clean = TRUE) {
 
   if (clean) {
-    data <- data_clean(data)
+    data <- data_clean(data, clean)
   }
 
   chunks <- list()
@@ -167,7 +167,7 @@ report_metrics <- function(data, cols, cross = NULL, metric = FALSE, ..., index
 report_counts <- function(data, cols, cross = NULL, metric = FALSE, index = FALSE, effect = FALSE, numbers = NULL, title = TRUE, close = TRUE, clean = TRUE, ...) {
 
   if (clean) {
-    data <- data_clean(data)
+    data <- data_clean(data, clean)
   }
 
   chunks <- list()
@@ -188,16 +188,16 @@ report_counts <- function(data, cols, cross = NULL, metric = FALSE, index = FALS
 
 
   # Add Plot
-  chunks <- plot_counts(data, {{ cols }}, {{ cross }}, ...,  effect = effect, title = plot_title, numbers=numbers, clean=clean) %>%
+  chunks <- plot_counts(data, {{ cols }}, {{ cross }}, metric = metric, effect = effect, title = plot_title, numbers=numbers, clean=clean, ...) %>%
     .add_to_vlkr_rprt(chunks, "Plot")
 
   # Add table
-  chunks <- tab_counts(data, {{ cols }}, {{ cross }},  effect = effect, clean=clean, ...) %>%
+  chunks <- tab_counts(data, {{ cols }}, {{ cross }}, metric = metric, effect = effect, clean=clean, ...) %>%
     .add_to_vlkr_rprt(chunks, "Table")
 
   # Add effect sizes
   if (effect) {
-    chunks <- effect_counts(data, {{ cols }}, {{ cross }}, effect = effect, clean=clean, ...) %>%
+    chunks <- effect_counts(data, {{ cols }}, {{ cross }}, metric = metric, effect = effect, clean=clean, ...) %>%
       .add_to_vlkr_rprt(chunks, "Effects")
   }
 
